==> qtjambi-designer-debuginfo-macos-5.15.17.jar: sources/QtJambiDesigner/QDesignerTaskMenuExtension_shell.cpp <==
#include "QDesignerTaskMenuExtension_shell.h"
#include <QtJambi/Cast>

void deleter_QDesignerTaskMenuExtension(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDesignerTaskMenuExtension")
    QDesignerTaskMenuExtension *_ptr = reinterpret_cast<QDesignerTaskMenuExtension *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDesignerTaskMenuExtension_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDesignerTaskMenuExtension_shell) ); }

jmethodID QDesignerTaskMenuExtension_shell::__shell_javaMethod(int pos) const { return QDesignerTaskMenuExtension_shell::__shell()->javaMethod(typeid(QDesignerTaskMenuExtension), pos); }

// emitting (writeShellConstructor)
QDesignerTaskMenuExtension_shell::QDesignerTaskMenuExtension_shell()
    : QDesignerTaskMenuExtension()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDesignerTaskMenuExtension::QDesignerTaskMenuExtension_shell()", QDesignerTaskMenuExtension_shell::__shell())
    QDesignerTaskMenuExtension_shell::__shell()->constructed(typeid(QDesignerTaskMenuExtension));
}

// emitting (writeShellDestructor)
QDesignerTaskMenuExtension_shell::~QDesignerTaskMenuExtension_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDesignerTaskMenuExtension::~QDesignerTaskMenuExtension()", QDesignerTaskMenuExtension_shell::__shell())
    QDesignerTaskMenuExtension_shell::__shell()->destructed(typeid(QDesignerTaskMenuExtension));
}

void QDesignerTaskMenuExtension_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDesignerTaskMenuExtension_shell*>(ptr)->QDesignerTaskMenuExtension_shell::__shell()->tryDeleteShell(typeid(QDesignerTaskMenuExtension));
}

// emitting Virtual overrides (virtualFunctions)
QAction* QDesignerTaskMenuExtension_shell::preferredEditAction() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDesignerTaskMenuExtension::", QDesignerTaskMenuExtension_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAction*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QDesignerTaskMenuExtension_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAction* >(__jni_env, __java_return_value);
                } else {
                    QDesignerTaskMenuExtension_shell::__shell()->warnForMethod("QDesignerTaskMenuExtension::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDesignerTaskMenuExtension::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QDesignerTaskMenuExtension::preferredEditAction();
        }
    }else{
        return QDesignerTaskMenuExtension::preferredEditAction();
    }
}

QList<QAction*> QDesignerTaskMenuExtension_shell::taskActions() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QDesignerTaskMenuExtension::", QDesignerTaskMenuExtension_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QList<QAction*>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QDesignerTaskMenuExtension_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QDesignerTaskMenuExtension_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QList<QAction*> >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QDesignerTaskMenuExtension_shell::__shell()->warnForMethod("QDesignerTaskMenuExtension::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDesignerTaskMenuExtension::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QList<QAction *>();
        }
    }else{
        return QList<QAction *>();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDesignerTaskMenuExtension_access::__qt_preferredEditAction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QAction* __qt_return_value = QDesignerTaskMenuExtension::preferredEditAction();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } else {
        QAction* __qt_return_value = preferredEditAction();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jobject QDesignerTaskMenuExtension_access::__qt_taskActions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QDesignerTaskMenuExtension::taskActions() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QDesignerTaskMenuExtension::taskActions() const.";
    } else {
        QList<QAction*> __qt_return_value = taskActions();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QDesignerTaskMenuExtension_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QDesignerTaskMenuExtension *__qt_this = new(__qtjambi_ptr) QDesignerTaskMenuExtension_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QDesignerTaskMenuExtension_shell
void __qt_destruct_QDesignerTaskMenuExtension(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDesignerTaskMenuExtension")
    reinterpret_cast<QDesignerTaskMenuExtension_shell*>(ptr)->~QDesignerTaskMenuExtension_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDesignerTaskMenuExtension::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerTaskMenuExtension_00024Impl_initialize_1native__Lio_qt_designer_QDesignerTaskMenuExtension_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesignerTaskMenuExtension::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDesignerTaskMenuExtension_0, sizeof(QDesignerTaskMenuExtension_shell), typeid(QDesignerTaskMenuExtension), true, &deleter_QDesignerTaskMenuExtension, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDesignerTaskMenuExtension::preferredEditAction()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerTaskMenuExtension_00024Impl_preferredEditAction_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDesignerTaskMenuExtension *__qt_this = QtJambiAPI::interfaceFromNativeId<QDesignerTaskMenuExtension>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDesignerTaskMenuExtension::preferredEditAction()const", __qt_this)
        __java_return_value = static_cast<const QDesignerTaskMenuExtension_access*>(__qt_this)->__qt_preferredEditAction(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDesignerTaskMenuExtension::taskActions()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerTaskMenuExtension_00024Impl_00024ConcreteWrapper_taskActions_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDesignerTaskMenuExtension *__qt_this = QtJambiAPI::interfaceFromNativeId<QDesignerTaskMenuExtension>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDesignerTaskMenuExtension::taskActions()const", __qt_this)
        __java_return_value = static_cast<const QDesignerTaskMenuExtension_access*>(__qt_this)->__qt_taskActions(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDesignerTaskMenuExtension(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QDesignerTaskMenuExtension>("QDesignerTaskMenuExtension", "io/qt/designer/QDesignerTaskMenuExtension");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "preferredEditAction", "()Lio/qt/widgets/QAction;"),
        FunctionInfo(/* 1 */ "taskActions", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QDesignerTaskMenuExtension, {
        ConstructorInfo(&__qt_construct_QDesignerTaskMenuExtension_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDesignerTaskMenuExtension);
    registerSizeOfShell(typeId, sizeof(QDesignerTaskMenuExtension_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QDesignerTaskMenuExtension* _object = dynamic_cast<QDesignerTaskMenuExtension*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QDesignerTaskMenuExtension *object = reinterpret_cast<QDesignerTaskMenuExtension *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QDesignerTaskMenuExtension *object = reinterpret_cast<const QDesignerTaskMenuExtension *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-designer-debuginfo-macos-5.15.20.jar: sources/QtJambiDesigner/QDesignerTaskMenuExtension_shell.cpp <==
#include "QDesignerTaskMenuExtension_shell.h"
#include <QtJambi/Cast>

void deleter_QDesignerTaskMenuExtension(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDesignerTaskMenuExtension")
    QDesignerTaskMenuExtension *_ptr = reinterpret_cast<QDesignerTaskMenuExtension *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDesignerTaskMenuExtension_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDesignerTaskMenuExtension_shell) ); }

jmethodID QDesignerTaskMenuExtension_shell::__shell_javaMethod(int pos) const { return QDesignerTaskMenuExtension_shell::__shell()->javaMethod(typeid(QDesignerTaskMenuExtension), pos); }

// emitting (writeShellConstructor)
QDesignerTaskMenuExtension_shell::QDesignerTaskMenuExtension_shell()
    : QDesignerTaskMenuExtension()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDesignerTaskMenuExtension::QDesignerTaskMenuExtension_shell()", QDesignerTaskMenuExtension_shell::__shell())
    QDesignerTaskMenuExtension_shell::__shell()->constructed(typeid(QDesignerTaskMenuExtension));
}

// emitting (writeShellDestructor)
QDesignerTaskMenuExtension_shell::~QDesignerTaskMenuExtension_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDesignerTaskMenuExtension::~QDesignerTaskMenuExtension()", QDesignerTaskMenuExtension_shell::__shell())
    QDesignerTaskMenuExtension_shell::__shell()->destructed(typeid(QDesignerTaskMenuExtension));
}

void QDesignerTaskMenuExtension_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDesignerTaskMenuExtension_shell*>(ptr)->QDesignerTaskMenuExtension_shell::__shell()->tryDeleteShell(typeid(QDesignerTaskMenuExtension));
}

// emitting Virtual overrides (virtualFunctions)
QAction* QDesignerTaskMenuExtension_shell::preferredEditAction() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDesignerTaskMenuExtension::", QDesignerTaskMenuExtension_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAction*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QDesignerTaskMenuExtension_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAction* >(__jni_env, __java_return_value);
                } else {
                    QDesignerTaskMenuExtension_shell::__shell()->warnForMethod("QDesignerTaskMenuExtension::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDesignerTaskMenuExtension::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QDesignerTaskMenuExtension::preferredEditAction();
        }
    }else{
        return QDesignerTaskMenuExtension::preferredEditAction();
    }
}

QList<QAction*> QDesignerTaskMenuExtension_shell::taskActions() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QDesignerTaskMenuExtension::", QDesignerTaskMenuExtension_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QList<QAction*>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QDesignerTaskMenuExtension_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QDesignerTaskMenuExtension_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QList<QAction*> >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QDesignerTaskMenuExtension_shell::__shell()->warnForMethod("QDesignerTaskMenuExtension::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDesignerTaskMenuExtension::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QList<QAction *>();
        }
    }else{
        return QList<QAction *>();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDesignerTaskMenuExtension_access::__qt_preferredEditAction_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QAction* __qt_return_value = QDesignerTaskMenuExtension::preferredEditAction();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } else {
        QAction* __qt_return_value = preferredEditAction();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jobject QDesignerTaskMenuExtension_access::__qt_taskActions_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QDesignerTaskMenuExtension::taskActions() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QDesignerTaskMenuExtension::taskActions() const.";
    } else {
        QList<QAction*> __qt_return_value = taskActions();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QDesignerTaskMenuExtension()
void __qt_construct_QDesignerTaskMenuExtension(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDesignerTaskMenuExtension()")
    Q_UNUSED(__java_arguments)
    QDesignerTaskMenuExtension *__qt_this = new(__qtjambi_ptr) QDesignerTaskMenuExtension_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDesignerTaskMenuExtension::QDesignerTaskMenuExtension()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerTaskMenuExtension_00024Impl_initialize_1native__Lio_qt_designer_QDesignerTaskMenuExtension_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesignerTaskMenuExtension::QDesignerTaskMenuExtension()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDesignerTaskMenuExtension, sizeof(QDesignerTaskMenuExtension_shell), typeid(QDesignerTaskMenuExtension), true, &deleter_QDesignerTaskMenuExtension, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDesignerTaskMenuExtension_shell
void __qt_destruct_QDesignerTaskMenuExtension(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDesignerTaskMenuExtension")
    reinterpret_cast<QDesignerTaskMenuExtension_shell*>(ptr)->~QDesignerTaskMenuExtension_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDesignerTaskMenuExtension::preferredEditAction()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerTaskMenuExtension_00024Impl_preferredEditAction_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDesignerTaskMenuExtension *__qt_this = QtJambiAPI::interfaceFromNativeId<QDesignerTaskMenuExtension>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDesignerTaskMenuExtension::preferredEditAction()const", __qt_this)
        __java_return_value = static_cast<const QDesignerTaskMenuExtension_access*>(__qt_this)->__qt_preferredEditAction_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDesignerTaskMenuExtension::taskActions()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerTaskMenuExtension_00024Impl_00024ConcreteWrapper_taskActions_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDesignerTaskMenuExtension *__qt_this = QtJambiAPI::interfaceFromNativeId<QDesignerTaskMenuExtension>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDesignerTaskMenuExtension::taskActions()const", __qt_this)
        __java_return_value = static_cast<const QDesignerTaskMenuExtension_access*>(__qt_this)->__qt_taskActions_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDesignerTaskMenuExtension(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QDesignerTaskMenuExtension>("QDesignerTaskMenuExtension", "io/qt/designer/QDesignerTaskMenuExtension");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "preferredEditAction", "()Lio/qt/widgets/QAction;"),
        FunctionInfo(/* 1 */ "taskActions", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QDesignerTaskMenuExtension, {
        ConstructorInfo(&__qt_construct_QDesignerTaskMenuExtension, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDesignerTaskMenuExtension);
    registerSizeOfShell(typeId, sizeof(QDesignerTaskMenuExtension_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QDesignerTaskMenuExtension* _object = dynamic_cast<QDesignerTaskMenuExtension*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QDesignerTaskMenuExtension *object = reinterpret_cast<QDesignerTaskMenuExtension *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QDesignerTaskMenuExtension *object = reinterpret_cast<const QDesignerTaskMenuExtension *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
